==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/MobileAppTroubleshootingAppTargetHistory.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.RunState;


/**
 * <i>“History Item contained in the Mobile App Troubleshooting Event.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "securityGroupId", 
    "runState", 
    "errorCode"})
@JsonInclude(Include.NON_NULL)
public class MobileAppTroubleshootingAppTargetHistory extends MobileAppTroubleshootingHistoryItem implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("securityGroupId")
    protected String securityGroupId;

    @JsonProperty("runState")
    protected RunState runState;

    @JsonProperty("errorCode")
    protected String errorCode;

    protected MobileAppTroubleshootingAppTargetHistory() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mobileAppTroubleshootingAppTargetHistory";
    }

    /**
     * <i>“AAD security group id to which it was targeted.”</i>
     * 
     * @return property securityGroupId
     */
    @Property(name="securityGroupId")
    @JsonIgnore
    public Optional<String> getSecurityGroupId() {
        return Optional.ofNullable(securityGroupId);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code securityGroupId}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“AAD security group id to which it was targeted.”</i>
     * 
     * @param securityGroupId
     *            new value of {@code securityGroupId} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code securityGroupId} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withSecurityGroupId(String securityGroupId) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.securityGroupId = securityGroupId;
        return _x;
    }

    /**
     * <i>“Status of the item.”</i>
     * 
     * @return property runState
     */
    @Property(name="runState")
    @JsonIgnore
    public Optional<RunState> getRunState() {
        return Optional.ofNullable(runState);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code runState} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Status of the item.”</i>
     * 
     * @param runState
     *            new value of {@code runState} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code runState} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withRunState(RunState runState) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.runState = runState;
        return _x;
    }

    /**
     * <i>“Error code for the failure, empty if no failure.”</i>
     * 
     * @return property errorCode
     */
    @Property(name="errorCode")
    @JsonIgnore
    public Optional<String> getErrorCode() {
        return Optional.ofNullable(errorCode);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code errorCode} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Error code for the failure, empty if no failure.”</i>
     * 
     * @param errorCode
     *            new value of {@code errorCode} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code errorCode} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withErrorCode(String errorCode) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.errorCode = errorCode;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMobileAppTroubleshootingAppTargetHistory() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime occurrenceDateTime;
        private DeviceManagementTroubleshootingErrorDetails troubleshootingErrorDetails;
        private String securityGroupId;
        private RunState runState;
        private String errorCode;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder occurrenceDateTime(OffsetDateTime occurrenceDateTime) {
            this.occurrenceDateTime = occurrenceDateTime;
            this.changedFields = changedFields.add("occurrenceDateTime");
            return this;
        }

        public Builder troubleshootingErrorDetails(DeviceManagementTroubleshootingErrorDetails troubleshootingErrorDetails) {
            this.troubleshootingErrorDetails = troubleshootingErrorDetails;
            this.changedFields = changedFields.add("troubleshootingErrorDetails");
            return this;
        }

        /**
         * <i>“AAD security group id to which it was targeted.”</i>
         * 
         * @param securityGroupId
         *            value of {@code securityGroupId} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder securityGroupId(String securityGroupId) {
            this.securityGroupId = securityGroupId;
            this.changedFields = changedFields.add("securityGroupId");
            return this;
        }

        /**
         * <i>“Status of the item.”</i>
         * 
         * @param runState
         *            value of {@code runState} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder runState(RunState runState) {
            this.runState = runState;
            this.changedFields = changedFields.add("runState");
            return this;
        }

        /**
         * <i>“Error code for the failure, empty if no failure.”</i>
         * 
         * @param errorCode
         *            value of {@code errorCode} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder errorCode(String errorCode) {
            this.errorCode = errorCode;
            this.changedFields = changedFields.add("errorCode");
            return this;
        }

        public MobileAppTroubleshootingAppTargetHistory build() {
            MobileAppTroubleshootingAppTargetHistory _x = new MobileAppTroubleshootingAppTargetHistory();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.mobileAppTroubleshootingAppTargetHistory";
            _x.occurrenceDateTime = occurrenceDateTime;
            _x.troubleshootingErrorDetails = troubleshootingErrorDetails;
            _x.securityGroupId = securityGroupId;
            _x.runState = runState;
            _x.errorCode = errorCode;
            return _x;
        }
    }

    private MobileAppTroubleshootingAppTargetHistory _copy() {
        MobileAppTroubleshootingAppTargetHistory _x = new MobileAppTroubleshootingAppTargetHistory();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.occurrenceDateTime = occurrenceDateTime;
        _x.troubleshootingErrorDetails = troubleshootingErrorDetails;
        _x.securityGroupId = securityGroupId;
        _x.runState = runState;
        _x.errorCode = errorCode;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MobileAppTroubleshootingAppTargetHistory[");
        b.append("occurrenceDateTime=");
        b.append(this.occurrenceDateTime);
        b.append(", ");
        b.append("troubleshootingErrorDetails=");
        b.append(this.troubleshootingErrorDetails);
        b.append(", ");
        b.append("securityGroupId=");
        b.append(this.securityGroupId);
        b.append(", ");
        b.append("runState=");
        b.append(this.runState);
        b.append(", ");
        b.append("errorCode=");
        b.append(this.errorCode);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/complex/MobileAppTroubleshootingAppTargetHistory.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.enums.RunState;


/**
 * <i>“History Item contained in the Mobile App Troubleshooting Event.”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "errorCode", 
    "runState", 
    "securityGroupId"})
@JsonInclude(Include.NON_NULL)
public class MobileAppTroubleshootingAppTargetHistory extends MobileAppTroubleshootingHistoryItem implements ODataType {

    @JsonProperty("errorCode")
    protected String errorCode;

    @JsonProperty("runState")
    protected RunState runState;

    @JsonProperty("securityGroupId")
    protected String securityGroupId;

    protected MobileAppTroubleshootingAppTargetHistory() {
        super();
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.mobileAppTroubleshootingAppTargetHistory";
    }

    /**
     * <i>“Error code for the failure, empty if no failure.”</i>
     * 
     * @return property errorCode
     */
    @Property(name="errorCode")
    @JsonIgnore
    public Optional<String> getErrorCode() {
        return Optional.ofNullable(errorCode);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code errorCode} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Error code for the failure, empty if no failure.”</i>
     * 
     * @param errorCode
     *            new value of {@code errorCode} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code errorCode} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withErrorCode(String errorCode) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.errorCode = errorCode;
        return _x;
    }

    /**
     * <i>“Status of the item.”</i>
     * 
     * @return property runState
     */
    @Property(name="runState")
    @JsonIgnore
    public Optional<RunState> getRunState() {
        return Optional.ofNullable(runState);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code runState} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Status of the item.”</i>
     * 
     * @param runState
     *            new value of {@code runState} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code runState} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withRunState(RunState runState) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.runState = runState;
        return _x;
    }

    /**
     * <i>“AAD security group id to which it was targeted.”</i>
     * 
     * @return property securityGroupId
     */
    @Property(name="securityGroupId")
    @JsonIgnore
    public Optional<String> getSecurityGroupId() {
        return Optional.ofNullable(securityGroupId);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code securityGroupId}
     * field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <i>“AAD security group id to which it was targeted.”</i>
     * 
     * @param securityGroupId
     *            new value of {@code securityGroupId} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code securityGroupId} field changed
     */
    public MobileAppTroubleshootingAppTargetHistory withSecurityGroupId(String securityGroupId) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.mobileAppTroubleshootingAppTargetHistory");
        _x.securityGroupId = securityGroupId;
        return _x;
    }

    public MobileAppTroubleshootingAppTargetHistory withUnmappedField(String name, Object value) {
        MobileAppTroubleshootingAppTargetHistory _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderMobileAppTroubleshootingAppTargetHistory() {
        return new Builder();
    }

    public static final class Builder {
        private OffsetDateTime occurrenceDateTime;
        private DeviceManagementTroubleshootingErrorDetails troubleshootingErrorDetails;
        private String errorCode;
        private RunState runState;
        private String securityGroupId;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder occurrenceDateTime(OffsetDateTime occurrenceDateTime) {
            this.occurrenceDateTime = occurrenceDateTime;
            this.changedFields = changedFields.add("occurrenceDateTime");
            return this;
        }

        public Builder troubleshootingErrorDetails(DeviceManagementTroubleshootingErrorDetails troubleshootingErrorDetails) {
            this.troubleshootingErrorDetails = troubleshootingErrorDetails;
            this.changedFields = changedFields.add("troubleshootingErrorDetails");
            return this;
        }

        /**
         * <i>“Error code for the failure, empty if no failure.”</i>
         * 
         * @param errorCode
         *            value of {@code errorCode} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder errorCode(String errorCode) {
            this.errorCode = errorCode;
            this.changedFields = changedFields.add("errorCode");
            return this;
        }

        /**
         * <i>“Status of the item.”</i>
         * 
         * @param runState
         *            value of {@code runState} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder runState(RunState runState) {
            this.runState = runState;
            this.changedFields = changedFields.add("runState");
            return this;
        }

        /**
         * <i>“AAD security group id to which it was targeted.”</i>
         * 
         * @param securityGroupId
         *            value of {@code securityGroupId} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder securityGroupId(String securityGroupId) {
            this.securityGroupId = securityGroupId;
            this.changedFields = changedFields.add("securityGroupId");
            return this;
        }

        public MobileAppTroubleshootingAppTargetHistory build() {
            MobileAppTroubleshootingAppTargetHistory _x = new MobileAppTroubleshootingAppTargetHistory();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.mobileAppTroubleshootingAppTargetHistory";
            _x.occurrenceDateTime = occurrenceDateTime;
            _x.troubleshootingErrorDetails = troubleshootingErrorDetails;
            _x.errorCode = errorCode;
            _x.runState = runState;
            _x.securityGroupId = securityGroupId;
            return _x;
        }
    }

    private MobileAppTroubleshootingAppTargetHistory _copy() {
        MobileAppTroubleshootingAppTargetHistory _x = new MobileAppTroubleshootingAppTargetHistory();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.occurrenceDateTime = occurrenceDateTime;
        _x.troubleshootingErrorDetails = troubleshootingErrorDetails;
        _x.errorCode = errorCode;
        _x.runState = runState;
        _x.securityGroupId = securityGroupId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("MobileAppTroubleshootingAppTargetHistory[");
        b.append("occurrenceDateTime=");
        b.append(this.occurrenceDateTime);
        b.append(", ");
        b.append("troubleshootingErrorDetails=");
        b.append(this.troubleshootingErrorDetails);
        b.append(", ");
        b.append("errorCode=");
        b.append(this.errorCode);
        b.append(", ");
        b.append("runState=");
        b.append(this.runState);
        b.append(", ");
        b.append("securityGroupId=");
        b.append(this.securityGroupId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
